function err=ShapeModel1Complete(shape,fraction,show)
%Complete a missing fraction of a shape based upon Shape Model 1
%Model 1 is a multivariate isotropic normal model with only 1 parameter:
%the standard deviation s.  For completion, we do not use this parameter.
%Rather, we simply plot the expected location.  Since the shapes have
%been pre-registered to a unit circle, the expected locations are regular
%samples along the unit circle.

len=length(shape);
t=2*pi*[1:len]'/len; %sample angle regularly, starting from +x axis
mu=exp(complex(0,t)); %expected locations

start=unidrnd(len); %select random starting point for occlusion
missinglen=round(fraction*len); %number of missing points
visiblelen=len-missinglen; %number of visible points
finish=start+round(fraction*len)-1; %finishing point for occlusion
missingIdx=mod([start:finish]'-1,len)+1; %idx sequence of missing points
visibleIdx=mod([finish+1:finish+visiblelen]'-1,len)+1; %idx sequence of visible points

err=sqrt(mean(abs(mu(missingIdx)-shape(missingIdx)).^2)); %RMS error


if show %display results
    %completed points, including visible endpoints for plotting purposes
    completion=[shape(mod(start-2,len)+1);mu(missingIdx);shape(mod(finish,len)+1)];
    %occluded points, including visible endpoints for plotting purposes
    occlusion=[shape(mod(start-2,len)+1);shape(missingIdx);shape(mod(finish,len)+1)];
    
    figure;
    plot(shape(visibleIdx));axis image;
    hold on;
    plot(occlusion,':');axis image;
    plot(completion,'r');axis image;
    axis off;
end