function s = ShapeModel1ML(shapes)
%Computes maximum likelihood parameters for Shape Model 1 from training
%data in shapes.
%Model 1 is a multivariate isotropic normal model with only 1 parameter:
%the standard deviation.
%Since the shapes have been pre-registered to a unit circle, 
%the expected locations are regular samples along the unit circle.

len=length(shapes{1});
t=2*pi*[1:len]'/len; %sample angle regularly, starting from +x axis
mu=exp(complex(0,t)); %expected locations

nshapes=length(shapes);
SSD=0;
for i=1:nshapes
    shape=shapes{i};
    SSD=SSD+sum(abs(shape-mu).^2); %sum of squared deviations
end
s=sqrt(SSD/(nshapes*len)); %sample standard deviation