function err=ShapeModel2Complete(S,shape,fraction,show)
%Complete a missing fraction of a shape based upon Shape Model 2
%Model 2 is a multivariate isotropic normal model with 2D(2D+1)/2 
%parameters: the covariance matrix S.
%Since the shapes have been pre-registered to a unit circle, 
%the expected locations are regular samples along the unit circle.

len=length(shape);
t=2*pi*[1:len]'/len; %sample angle regularly, starting from +x axis
mu=exp(complex(0,t)); %expected locations

start=unidrnd(len); %select random starting point for occlusion
missinglen=round(fraction*len); %number of missing points
visiblelen=len-missinglen; %number of visible points
finish=start+round(fraction*len)-1; %finishing point for occlusion
missingIdx=mod([start:finish]'-1,len)+1; %idx sequence of missing points
visibleIdx=mod([finish+1:finish+visiblelen]'-1,len)+1; %idx sequence of visible points

L=S^-1; %Precision matrix
Lmm = L(missingIdx,:); %Missing partition
Lmm = Lmm(:,missingIdx);
Lmv = L(missingIdx,:); %Missing-visible partition 
Lmv = Lmv(:,visibleIdx);

%Mean of missing conditioned on visible - see Bishop Eq.2.97
completion=mu(missingIdx)-Lmm^-1*Lmv*(shape(visibleIdx)-mu(visibleIdx));
err=sqrt(mean(abs(completion-shape(missingIdx)).^2)); %RMS error

if show %display results
    %completed points, including visible endpoints for plotting purposes
    completion=[shape(mod(start-2,len)+1);completion;shape(mod(finish,len)+1)];
    %occluded points, including visible endpoints for plotting purposes
    occlusion=[shape(mod(start-2,len)+1);shape(missingIdx);shape(mod(finish,len)+1)];
    
    figure;
    plot(shape(visibleIdx));axis image;
    hold on;
    plot(occlusion,':');axis image;
    plot(completion,'r');axis image;
    axis off;
end