function S = ShapeModel2ML(shapes)
%Computes maximum likelihood parameters for Shape Model 2 from training
%data in shapes.
%Model 2 is a multivariate isotropic normal model with 2D(2D+1)/2 
%parameters: the covariance matrix S.
%Since the shapes have been pre-registered to a unit circle, 
%the expected locations are regular samples along the unit circle.

len=length(shapes{1});
t=2*pi*[1:len]'/len; %sample angle regularly, starting from +x axis
mu=exp(complex(0,t)); %expected locations

nshapes=length(shapes);
S=0;
for i=1:nshapes
    shape=shapes{i};
    S=S+(shape-mu)*(shape-mu)'; %build sample covarariance
end
S=S/nshapes; %sample covariance