function ShapeModel2Sample(S,nsamples)
%Sample from Shape Model 2
%Model 2 is a multivariate isotropic normal model with 2D(2D+1)/2 
%parameters: the covariance matrix.
%Since the shapes have been pre-registered to a unit circle, 
%the expected locations are regular samples along the unit circle.

len=size(S,1);
t=2*pi*[1:len]'/len; %sample angle regularly, starting from +x axis
mu=exp(complex(0,t)); %expected locations

nrows=ceil(sqrt(nsamples)); %number of rows in multi-panel plot
ncols=ceil(nsamples/nrows); %number of columns in multi-panel plot
figure;

for i=1:nsamples
    shape=mvnrnd(mu,S); %sample shape
    shape=[shape,shape(1)]; %close shape
    subplot(nrows,ncols,i); %plot in panel i
    plot(shape);axis image;
    axis off;
end