function err=ShapeModel3Complete(shape,fraction,show)
%Complete a missing fraction of a shape based upon linear interpolation.

len=length(shape);

start=unidrnd(len); %select random starting point for occlusion
missinglen=round(fraction*len); %number of missing points
visiblelen=len-missinglen; %number of visible points
finish=start+round(fraction*len)-1; %finishing point for occlusion
missingIdx=mod([start:finish]'-1,len)+1; %idx sequence of missing points
visibleIdx=mod([finish+1:finish+visiblelen]'-1,len)+1; %idx sequence of visible points

a=[1:missinglen]'/(missinglen+1); %arclength along linear interpolant
endpoint1=shape(mod(start-2,len)+1); %first visible endpoint
endpoint2=shape(mod(finish,len)+1); %second visible endpoint
completion=a*endpoint1+(1-a)*endpoint2; %linear interpolation

err=sqrt(mean(abs(completion-shape(missingIdx)).^2)); %RMS error

if show %display results
    %completed points, including visible endpoints for plotting purposes
    completion=[shape(mod(start-2,len)+1);completion;shape(mod(finish,len)+1)];
    %occluded points, including visible endpoints for plotting purposes
    occlusion=[shape(mod(start-2,len)+1);shape(missingIdx);shape(mod(finish,len)+1)];

    figure;
    plot(shape(visibleIdx));axis image;
    hold on;
    plot(occlusion,':');axis image;
    plot(completion,'r');axis image;
    axis off;
end